skosprovider_rdf
================

Skosprovider implementation based on RDF


.. image:: https://travis-ci.org/OnroerendErfgoed/skosprovider_rdf.png?branch=master
        :target: https://travis-ci.org/OnroerendErfgoed/skosprovider_rdf
.. image:: https://coveralls.io/repos/OnroerendErfgoed/skosprovider_rdf/badge.png?branch=master
        :target: https://coveralls.io/r/OnroerendErfgoed/skosprovider_rdf
.. image:: https://badge.fury.io/py/skosprovider_rdf.png
        :target: http://badge.fury.io/py/skosprovider_rdf
